# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-01-21 15:44
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0003_auto_20190121_1541'),
    ]

    operations = [
        migrations.RenameField(
            model_name='project',
            old_name='members',
            new_name='team',
        ),
    ]
