# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-01-21 15:41
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('djangoldp_project', '0002_move_jabber'),
    ]

    operations = [
        migrations.CreateModel(
            name='Job',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
            ],
        ),
        migrations.RemoveField(
            model_name='project',
            name='team',
        ),
        migrations.AddField(
            model_name='customer',
            name='companyRegister',
            field=models.CharField(default='', max_length=255),
        ),
        migrations.AddField(
            model_name='customer',
            name='contactFirstName',
            field=models.CharField(default='', max_length=255),
        ),
        migrations.AddField(
            model_name='customer',
            name='contactLastName',
            field=models.CharField(default='', max_length=255),
        ),
        migrations.AddField(
            model_name='customer',
            name='contactMail',
            field=models.EmailField(default='', max_length=254),
        ),
        migrations.AddField(
            model_name='customer',
            name='contactPhone',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='project',
            name='businessProvider',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='project',
            name='businessProviderFee',
            field=models.PositiveIntegerField(blank=True, default='0'),
        ),
        migrations.AddField(
            model_name='job',
            name='project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djangoldp_project.Project'),
        ),
        migrations.AddField(
            model_name='job',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='project',
            name='members',
            field=models.ManyToManyField(blank=True, through='djangoldp_project.Job', to=settings.AUTH_USER_MODEL),
        ),
    ]
